## Monte Carlo simulation to determine if realized reproductive success differs betwen Florida scrub-jays bredding locally, dispersing from suburbs, or dispersing from wildlands.

##Results published in: Tringali & Bowman 2015. Suburban immigrants to wildlands disrupt honest signaling in ultra-violet plumage. Avian Conservation & Ecology 10(1): 9.

#Load and attach data
rm(list=ls())

file_name <- "FSJ_RealizedRS_by_disp.txt"
data <- read.table(file_name, header=T)
attach(data)
names(data)

##Define realized reproductive success as standarded number of breeders produced minus standardized number of hatchlings
Variable <- zBrdr.ZHtch

## Calculate mean and standard error for the three dispersal types
mean_S <- mean(Variable[DispersalType=="s_to_w"])
se_S <- sqrt((var(Variable[DispersalType=="s_to_w"])/length(Variable[DispersalType=="s_to_w"])))
mean_W <- mean(Variable[DispersalType=="w_to_w"])
se_W <- sqrt((var(Variable[DispersalType=="w_to_w"])/length(Variable[DispersalType=="w_to_w"])))
mean_local <- mean(Variable[DispersalType=="local"])
se_local <- sqrt((var(Variable[DispersalType=="local"])/length(Variable[DispersalType=="local"])))
mean_S 
se_S
mean_W
se_W
mean_local
se_local


##Calcuate observed differences in realized reproductive success between dispersal types
diff_Obs_S_W <- abs(mean_S - mean_W)
diff_Obs_W_local <- abs(mean_W - mean_local)
diff_Obs_S_local <- abs(mean_S - mean_local)
diff_Obs_S_W
diff_Obs_W_local
diff_Obs_S_local

##S W Diffs
iterations <- 1000
diffs_S_W <- numeric(iterations)

for (i in 1:iterations) {
	
Dispersal_randomized <- sample(DispersalType, length(DispersalType))
Variable_randomized <- Variable
randomized_data <- data.frame(Dispersal_randomized, Variable_randomized)

randomized_S <- mean(Variable_randomized[Dispersal_randomized=="s_to_w"])
randomized_W <- mean(Variable_randomized[Dispersal_randomized=="w_to_w"])
#randomized_local <- mean(Variable_randomized[Dispersal_randomized=="local"])

diffs_S_W[i] <- abs(randomized_S - randomized_W)
i <- i+1
}

hist(diffs_S_W, xlab="Difference")
abline(v=diff_Obs_S_W, col = "red")

P_MC <- length(diffs_S_W[diffs_S_W>=diff_Obs_S_W])/iterations
P_MC

## S Local Diffs
iterations <- 1000
diffs_S_local <- numeric(iterations)

for (i in 1:iterations) {
	
Dispersal_randomized <- sample(DispersalType, length(DispersalType))
Variable_randomized <- Variable
randomized_data <- data.frame(Dispersal_randomized, Variable_randomized)

randomized_S <- mean(Variable_randomized[Dispersal_randomized=="s_to_w"])
randomized_W <- mean(Variable_randomized[Dispersal_randomized=="w_to_w"])
randomized_local <- mean(Variable_randomized[Dispersal_randomized=="local"])

diffs_S_local[i] <- abs(randomized_S - randomized_local)
i <- i+1
}

hist(diffs_S_local, xlab="Difference")
abline(v=diff_Obs_S_local, col = "red")

P_MC <- length(diffs_S_local[diffs_S_local>=diff_Obs_S_local])/iterations
P_MC

## W Local Diffs
iterations <- 1000
diffs_W_local <- numeric(iterations)

for (i in 1:iterations) {
	
Dispersal_randomized <- sample(DispersalType, length(DispersalType))
Variable_randomized <- Variable
randomized_data <- data.frame(Dispersal_randomized, Variable_randomized)

randomized_S <- mean(Variable_randomized[Dispersal_randomized=="s_to_w"])
randomized_W <- mean(Variable_randomized[Dispersal_randomized=="w_to_w"])
randomized_local <- mean(Variable_randomized[Dispersal_randomized=="local"])

diffs_W_local[i] <- abs(randomized_W - randomized_local)
i <- i+1
}

hist(diffs_W_local, xlab="Difference")
abline(v=diff_Obs_W_local, col = "red")

P_MC <- length(diffs_W_local[diffs_W_local>=diff_Obs_W_local])/iterations
P_MC

